# Changelog

## [0.0.3a2](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/tree/0.0.3a2) (2024-09-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/compare/V0.0.3a1...0.0.3a2)

**Merged pull requests:**

- feat:semver [\#3](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/pull/3) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.3a1](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/tree/V0.0.3a1) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/compare/V0.0.2...V0.0.3a1)

**Merged pull requests:**

- fix/dependencies [\#2](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/pull/2) ([NeonJarbas](https://github.com/NeonJarbas))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
